@@ -1,38 +1,38 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the demonstration applications of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** GNU Lesser General Public License Usage
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this
-** file. Please review the following information to ensure the GNU Lesser
-** General Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU General
-** Public License version 3.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of this
-** file. Please review the following information to ensure the GNU General
-** Public License version 3.0 requirements will be met:
-** http://www.gnu.org/copyleft/gpl.html.
-**
-** Other Usage
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-**
-**
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
 **
 ** $QT_END_LICENSE$
@@ -518,16 +518,28 @@ QString MenuManager::resolveExeFile(const QString &name)
     dir.cd(dirName);
     dir.cd(fileName);
 
-    fileName = fileName.split("/").last();
-    QFile unixFile(dir.path() + "/" + fileName);
-    if (unixFile.exists()) return unixFile.fileName();
-    QFile winR(dir.path() + "\\release\\" + fileName + ".exe");
-    if (winR.exists()) return winR.fileName();
-    QFile winD(dir.path() + "\\debug\\" + fileName + ".exe");
-    if (winD.exists()) return winD.fileName();
-    QFile mac(dir.path() + "/" + fileName + ".app");
-    if (mac.exists()) return mac.fileName();
-
+    fileName = fileName.split(QLatin1Char('/')).last();
+#ifdef Q_OS_WIN
+    fileName += QLatin1String(".exe");
+#endif
+    // UNIX, Mac non-framework and Windows installed builds.
+    const QFile installedFile(dir.path() + QLatin1Char('/') + fileName);
+    if (installedFile.exists())
+        return installedFile.fileName();
+    // Windows in-source builds
+#if defined(Q_OS_WIN)
+    const QFile winR(dir.path() + QLatin1String("/release/") + fileName);
+    if (winR.exists())
+        return winR.fileName();
+    const QFile winD(dir.path() + QLatin1String("/debug/") + fileName);
+    if (winD.exists())
+        return winD.fileName();
+#elif defined(Q_OS_MAC)
+    // Mac frameworks
+    const QFile mac(dir.path() + QLatin1Char('/') + fileName + QLatin1String(".app"));
+    if (mac.exists())
+        return mac.fileName();
+#endif
     if (Colors::verbose)
         qDebug() << "- WARNING: Could not resolve executable:" << dir.path() << fileName;
     return "__executable not found__";
