@@ -1,8 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the ActiveQt framework of the Qt Toolkit.
 **
@@ -18,10 +17,10 @@
 **     notice, this list of conditions and the following disclaimer in
 **     the documentation and/or other materials provided with the
 **     distribution.
-**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
-**     the names of its contributors may be used to endorse or promote
-**     products derived from this software without specific prior written
-**     permission.
+**   * Neither the name of Digia Plc and its Subsidiary(-ies) nor the names
+**     of its contributors may be used to endorse or promote products derived
+**     from this software without specific prior written permission.
+**
 **
 ** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 ** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -34,6 +33,7 @@
 ** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 ** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 ** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
+**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -408,7 +408,7 @@ private:
     CONTROLINFO control_info;
 
     QSize sizehint;
-    unsigned long ref;
+    LONG ref;
     QAxWidget *widget;
     QAxHostWidget *host;
 #if !defined(Q_WS_WINCE)
@@ -560,7 +560,6 @@ bool QAxClientSite::activateObject(bool initialized, const QByteArray &data)
         host = new QAxHostWidget(widget, this);
 
     bool showHost = false;
-    HRESULT hr = S_OK;
     if (!m_spOleObject)
         widget->queryInterface(IID_IOleObject, (void**)&m_spOleObject);
     if (m_spOleObject) {
@@ -577,8 +576,8 @@ bool QAxClientSite::activateObject(bool initialized, const QByteArray &data)
             // try to activate as document server
                 IStorage *storage = 0;
                 ILockBytes * bytes = 0;
-                HRESULT hres = ::CreateILockBytesOnHGlobal(0, TRUE, &bytes);
-                hres = ::StgCreateDocfileOnILockBytes(bytes, STGM_SHARE_EXCLUSIVE|STGM_CREATE|STGM_READWRITE, 0, &storage);
+                ::CreateILockBytesOnHGlobal(0, TRUE, &bytes);
+                ::StgCreateDocfileOnILockBytes(bytes, STGM_SHARE_EXCLUSIVE|STGM_CREATE|STGM_READWRITE, 0, &storage);
 
                 persistStorage->InitNew(storage);
                 persistStorage->Release();
@@ -663,8 +662,9 @@ bool QAxClientSite::activateObject(bool initialized, const QByteArray &data)
         if (spAdviseSink && spViewObject) {
             if (spViewObject)
                 spViewObject->SetAdvise(DVASPECT_CONTENT, 0, spAdviseSink);
-            spAdviseSink->Release();
         }
+        if (spAdviseSink)
+            spAdviseSink->Release();
         if (spViewObject)
             spViewObject->Release();
 
@@ -693,7 +693,7 @@ bool QAxClientSite::activateObject(bool initialized, const QByteArray &data)
 
         RECT rcPos = { host->x(), host->y(), host->x()+sizehint.width(), host->y()+sizehint.height() };
 
-        hr = m_spOleObject->DoVerb(OLEIVERB_INPLACEACTIVATE, 0, (IOleClientSite*)this, 0, host->winId(), &rcPos);
+        m_spOleObject->DoVerb(OLEIVERB_INPLACEACTIVATE, 0, (IOleClientSite*)this, 0, host->winId(), &rcPos);
 
         if (!m_spOleControl)
             m_spOleObject->QueryInterface(IID_IOleControl, (void**)&m_spOleControl);
@@ -774,16 +774,16 @@ void QAxClientSite::deactivate()
 //**** IUnknown
 unsigned long WINAPI QAxClientSite::AddRef()
 {
-    return ++ref;
+    return InterlockedIncrement(&ref);
 }
 
 unsigned long WINAPI QAxClientSite::Release()
 {
-    if (!--ref) {
+    LONG refCount = InterlockedDecrement(&ref);
+    if (!refCount)
         delete this;
-        return 0;
-    }
-    return ref;
+
+    return refCount;
 }
 
 HRESULT WINAPI QAxClientSite::QueryInterface(REFIID iid, void **iface)
@@ -2148,7 +2148,7 @@ QSize QAxWidget::minimumSizeHint() const
 */
 void QAxWidget::changeEvent(QEvent *e)
 {
-    if (isNull())
+    if (isNull() || !container)
         return;
 
     switch (e->type()) {
