@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
@@ -132,7 +132,7 @@ void QFSFileEnginePrivate::init()
 #ifdef Q_OS_WIN
     fileAttrib = INVALID_FILE_ATTRIBUTES;
     fileHandle = INVALID_HANDLE_VALUE;
-    mapHandle = INVALID_HANDLE_VALUE;
+    mapHandle = NULL;
 #ifndef Q_OS_WINCE
     cachedFd = -1;
 #endif
@@ -777,6 +777,7 @@ qint64 QFSFileEnginePrivate::writeFdFh(const char *data, qint64 len)
     return writtenBytes;
 }
 
+#ifndef QT_NO_FILESYSTEMITERATOR
 /*!
     \internal
 */
@@ -792,6 +793,7 @@ QAbstractFileEngine::Iterator *QFSFileEngine::endEntryList()
 {
     return 0;
 }
+#endif
 
 /*!
     \internal
