@@ -1,38 +1,38 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** GNU Lesser General Public License Usage
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this
-** file. Please review the following information to ensure the GNU Lesser
-** General Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU General
-** Public License version 3.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of this
-** file. Please review the following information to ensure the GNU General
-** Public License version 3.0 requirements will be met:
-** http://www.gnu.org/copyleft/gpl.html.
-**
-** Other Usage
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-**
-**
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
 **
 ** $QT_END_LICENSE$
@@ -40,6 +40,9 @@
 ****************************************************************************/
 
 #include "qmouseqnx_qws.h"
+#ifndef QT_NO_QWS_TRANSFORMED
+#include "qscreen_qws.h"
+#endif
 
 #include "qplatformdefs.h"
 #include "qsocketnotifier.h"
@@ -113,6 +116,9 @@ QQnxMouseHandler::QQnxMouseHandler(const QString & driver, const QString &device
 
         qDebug("QQnxMouseHandler: connected.");
     }
+#ifndef QT_NO_QWS_TRANSFORMED
+    transformedMousePos = QPoint(qt_screen->deviceWidth() / 2, qt_screen->deviceHeight() / 2);
+#endif
 }
 
 /*!
@@ -146,7 +152,11 @@ void QQnxMouseHandler::suspend()
 */
 void QQnxMouseHandler::socketActivated()
 {
+#ifndef QT_NO_QWS_TRANSFORMED
+    QPoint queuedPos = transformedMousePos;
+#else
     QPoint queuedPos = mousePos;
+#endif
 
     // _mouse_packet is a QNX structure. devi-hid is nice enough to translate
     // the raw byte data from mouse devices into generic format for us.
@@ -196,13 +206,24 @@ void QQnxMouseHandler::socketActivated()
             // send the MouseEvent to avoid missing any clicks
             mouseChanged(queuedPos, buttons, 0);
             // mousePos updated by the mouseChanged()
+#ifndef QT_NO_QWS_TRANSFORMED
+            queuedPos = transformedMousePos;
+#else
             queuedPos = mousePos;
+#endif
             mouseButtons = buttons;
         }
     }
 
+#ifndef QT_NO_QWS_TRANSFORMED
+    if (queuedPos != transformedMousePos) {
+        mouseChanged(queuedPos, mouseButtons, 0);
+        transformedMousePos = queuedPos;
+    }
+#else
     if (queuedPos != mousePos)
         mouseChanged(queuedPos, mouseButtons, 0);
+#endif
 }
 
 QT_END_NAMESPACE
