@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
@@ -502,6 +502,10 @@ void QQnxScreen::exposeRegion(QRegion r, int changing)
     // the region on our in-memory surface
     QScreen::exposeRegion(r, changing);
 
+#ifndef QT_NO_QWS_TRANSFORMED
+    if (qt_screen->isTransformed())
+        return;
+#endif
     // now our in-memory surface should be up to date with the latest changes.
 
     if (!d->hwSurface)
@@ -509,26 +513,22 @@ void QQnxScreen::exposeRegion(QRegion r, int changing)
 
     // the code below copies the region from the in-memory surface to the hardware.
 
-    // just get the bounding rectangle of the region. Most screen updates are rectangular
-    // anyways. Code could be optimized to blit each and every member of the region
-    // individually, but in real life, the speed-up is neglectable
-    const QRect br = r.boundingRect();
-    if (br.isEmpty())
-        return; // ignore empty regions because gf_draw_blit2 doesn't like 0x0 dimensions
-
     // start drawing.
     int ret = gf_draw_begin(d->context);
     if (ret != GF_ERR_OK) {
         qWarning("QQnxScreen: gf_draw_begin() failed with error code %d", ret);
         return;
     }
-
-    // blit the changed region from the memory surface to the hardware surface
-    ret = gf_draw_blit2(d->context, d->memSurface, d->hwSurface,
-                        br.x(), br.y(), br.right(), br.bottom(), br.x(), br.y());
-    if (ret != GF_ERR_OK)
-        qWarning("QQnxScreen: gf_draw_blit2() failed with error code %d", ret);
-
+    QVector<QRect> rects = r.rects();
+    Q_FOREACH (QRect rect, rects) {
+        if (!rect.isEmpty()) {
+            // blit the changed region from the memory surface to the hardware surface
+            ret = gf_draw_blit2(d->context, d->memSurface, d->hwSurface,
+                                rect.x(), rect.y(), rect.right(), rect.bottom(), rect.x(), rect.y());
+            if (ret != GF_ERR_OK)
+                qWarning("QQnxScreen: gf_draw_blit2() failed with error code %d", ret);
+        }
+    }
     // flush all drawing commands (in our case, a single blit)
     ret = gf_draw_flush(d->context);
     if (ret != GF_ERR_OK)
@@ -538,4 +538,36 @@ void QQnxScreen::exposeRegion(QRegion r, int changing)
     gf_draw_end(d->context);
 }
 
+#ifndef QT_NO_QWS_TRANSFORMED
+void QQnxScreen::setDirty(const QRect &r)
+{
+    //This function is called only when the screen is transformed
+    if (!qt_screen->isTransformed())
+        return;
+
+    if (!d->hwSurface)
+        return;
+
+    int ret = gf_draw_begin(d->context);
+
+    if (ret != GF_ERR_OK) {
+        qWarning("QQnxScreen: gf_draw_begin() failed with error code %d in setDirty", ret);
+        return;
+    }
+
+    // blit the changed region from the memory surface to the hardware surface
+    ret = gf_draw_blit2(d->context, d->memSurface, d->hwSurface,
+                        r.x(), r.y(), r.x()+ r.width(), r.y()+r.height(), r.x(), r.y());
+    if (ret != GF_ERR_OK)
+        qWarning("QQnxScreen: gf_draw_blit2() failed with error code %d in setDirty", ret);
+
+    ret = gf_draw_flush(d->context);
+    if (ret != GF_ERR_OK)
+        qWarning("QQnxScreen: gf_draw_flush() failed with error code %d in setDirty", ret);
+
+    // tell QNX that we're done drawing.
+    gf_draw_end(d->context);
+}
+#endif
+
 QT_END_NAMESPACE
