@@ -1,38 +1,38 @@
 /****************************************************************************
 **
-** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** GNU Lesser General Public License Usage
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this
-** file. Please review the following information to ensure the GNU Lesser
-** General Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU General
-** Public License version 3.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of this
-** file. Please review the following information to ensure the GNU General
-** Public License version 3.0 requirements will be met:
-** http://www.gnu.org/copyleft/gpl.html.
-**
-** Other Usage
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-**
-**
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
 **
 ** $QT_END_LICENSE$
@@ -287,106 +287,104 @@ bool QGestureManager::filterEventThroughContexts(const QMultiMap<QObject *,
             }
         }
     }
-    if (triggeredGestures.isEmpty() && finishedGestures.isEmpty()
-        && newMaybeGestures.isEmpty() && notGestures.isEmpty())
-        return consumeEventHint;
+    if (!triggeredGestures.isEmpty() || !finishedGestures.isEmpty()
+        || !newMaybeGestures.isEmpty() || !notGestures.isEmpty()) {
+        QSet<QGesture *> startedGestures = triggeredGestures - m_activeGestures;
+        triggeredGestures &= m_activeGestures;
 
-    QSet<QGesture *> startedGestures = triggeredGestures - m_activeGestures;
-    triggeredGestures &= m_activeGestures;
+        // check if a running gesture switched back to maybe state
+        QSet<QGesture *> activeToMaybeGestures = m_activeGestures & newMaybeGestures;
 
-    // check if a running gesture switched back to maybe state
-    QSet<QGesture *> activeToMaybeGestures = m_activeGestures & newMaybeGestures;
+        // check if a maybe gesture switched to canceled - reset it but don't send an event
+        QSet<QGesture *> maybeToCanceledGestures = m_maybeGestures & notGestures;
 
-    // check if a maybe gesture switched to canceled - reset it but don't send an event
-    QSet<QGesture *> maybeToCanceledGestures = m_maybeGestures & notGestures;
+        // check if a running gesture switched back to not gesture state,
+        // i.e. were canceled
+        QSet<QGesture *> canceledGestures = m_activeGestures & notGestures;
 
-    // check if a running gesture switched back to not gesture state,
-    // i.e. were canceled
-    QSet<QGesture *> canceledGestures = m_activeGestures & notGestures;
+        // new gestures in maybe state
+        m_maybeGestures += newMaybeGestures;
 
-    // new gestures in maybe state
-    m_maybeGestures += newMaybeGestures;
+        // gestures that were in maybe state
+        QSet<QGesture *> notMaybeGestures = (startedGestures | triggeredGestures
+                                             | finishedGestures | canceledGestures
+                                             | notGestures);
+        m_maybeGestures -= notMaybeGestures;
 
-    // gestures that were in maybe state
-    QSet<QGesture *> notMaybeGestures = (startedGestures | triggeredGestures
-                                         | finishedGestures | canceledGestures
-                                         | notGestures);
-    m_maybeGestures -= notMaybeGestures;
+        Q_ASSERT((startedGestures & finishedGestures).isEmpty());
+        Q_ASSERT((startedGestures & newMaybeGestures).isEmpty());
+        Q_ASSERT((startedGestures & canceledGestures).isEmpty());
+        Q_ASSERT((finishedGestures & newMaybeGestures).isEmpty());
+        Q_ASSERT((finishedGestures & canceledGestures).isEmpty());
+        Q_ASSERT((canceledGestures & newMaybeGestures).isEmpty());
 
-    Q_ASSERT((startedGestures & finishedGestures).isEmpty());
-    Q_ASSERT((startedGestures & newMaybeGestures).isEmpty());
-    Q_ASSERT((startedGestures & canceledGestures).isEmpty());
-    Q_ASSERT((finishedGestures & newMaybeGestures).isEmpty());
-    Q_ASSERT((finishedGestures & canceledGestures).isEmpty());
-    Q_ASSERT((canceledGestures & newMaybeGestures).isEmpty());
+        QSet<QGesture *> notStarted = finishedGestures - m_activeGestures;
+        if (!notStarted.isEmpty()) {
+            // there are some gestures that claim to be finished, but never started.
+            // probably those are "singleshot" gestures so we'll fake the started state.
+            foreach (QGesture *gesture, notStarted)
+                gesture->d_func()->state = Qt::GestureStarted;
+            QSet<QGesture *> undeliveredGestures;
+            deliverEvents(notStarted, &undeliveredGestures);
+            finishedGestures -= undeliveredGestures;
+        }
 
-    QSet<QGesture *> notStarted = finishedGestures - m_activeGestures;
-    if (!notStarted.isEmpty()) {
-        // there are some gestures that claim to be finished, but never started.
-        // probably those are "singleshot" gestures so we'll fake the started state.
-        foreach (QGesture *gesture, notStarted)
+        m_activeGestures += startedGestures;
+        // sanity check: all triggered gestures should already be in active gestures list
+        Q_ASSERT((m_activeGestures & triggeredGestures).size() == triggeredGestures.size());
+        m_activeGestures -= finishedGestures;
+        m_activeGestures -= activeToMaybeGestures;
+        m_activeGestures -= canceledGestures;
+
+        // set the proper gesture state on each gesture
+        foreach (QGesture *gesture, startedGestures)
             gesture->d_func()->state = Qt::GestureStarted;
+        foreach (QGesture *gesture, triggeredGestures)
+            gesture->d_func()->state = Qt::GestureUpdated;
+        foreach (QGesture *gesture, finishedGestures)
+            gesture->d_func()->state = Qt::GestureFinished;
+        foreach (QGesture *gesture, canceledGestures)
+            gesture->d_func()->state = Qt::GestureCanceled;
+        foreach (QGesture *gesture, activeToMaybeGestures)
+            gesture->d_func()->state = Qt::GestureFinished;
+
+        if (!m_activeGestures.isEmpty() || !m_maybeGestures.isEmpty() ||
+            !startedGestures.isEmpty() || !triggeredGestures.isEmpty() ||
+            !finishedGestures.isEmpty() || !canceledGestures.isEmpty()) {
+            DEBUG() << "QGestureManager::filterEventThroughContexts:"
+                    << "\n\tactiveGestures:" << m_activeGestures
+                    << "\n\tmaybeGestures:" << m_maybeGestures
+                    << "\n\tstarted:" << startedGestures
+                    << "\n\ttriggered:" << triggeredGestures
+                    << "\n\tfinished:" << finishedGestures
+                    << "\n\tcanceled:" << canceledGestures
+                    << "\n\tmaybe-canceled:" << maybeToCanceledGestures;
+        }
+
         QSet<QGesture *> undeliveredGestures;
-        deliverEvents(notStarted, &undeliveredGestures);
-        finishedGestures -= undeliveredGestures;
-    }
+        deliverEvents(startedGestures+triggeredGestures+finishedGestures+canceledGestures,
+                      &undeliveredGestures);
 
-    m_activeGestures += startedGestures;
-    // sanity check: all triggered gestures should already be in active gestures list
-    Q_ASSERT((m_activeGestures & triggeredGestures).size() == triggeredGestures.size());
-    m_activeGestures -= finishedGestures;
-    m_activeGestures -= activeToMaybeGestures;
-    m_activeGestures -= canceledGestures;
+        foreach (QGesture *g, startedGestures) {
+            if (undeliveredGestures.contains(g))
+                continue;
+            if (g->gestureCancelPolicy() == QGesture::CancelAllInContext) {
+                DEBUG() << "lets try to cancel some";
+                // find gestures in context in Qt::GestureStarted or Qt::GestureUpdated state and cancel them
+                cancelGesturesForChildren(g);
+            }
+        }
 
-    // set the proper gesture state on each gesture
-    foreach (QGesture *gesture, startedGestures)
-        gesture->d_func()->state = Qt::GestureStarted;
-    foreach (QGesture *gesture, triggeredGestures)
-        gesture->d_func()->state = Qt::GestureUpdated;
-    foreach (QGesture *gesture, finishedGestures)
-        gesture->d_func()->state = Qt::GestureFinished;
-    foreach (QGesture *gesture, canceledGestures)
-        gesture->d_func()->state = Qt::GestureCanceled;
-    foreach (QGesture *gesture, activeToMaybeGestures)
-        gesture->d_func()->state = Qt::GestureFinished;
+        m_activeGestures -= undeliveredGestures;
 
-    if (!m_activeGestures.isEmpty() || !m_maybeGestures.isEmpty() ||
-        !startedGestures.isEmpty() || !triggeredGestures.isEmpty() ||
-        !finishedGestures.isEmpty() || !canceledGestures.isEmpty()) {
-        DEBUG() << "QGestureManager::filterEventThroughContexts:"
-                << "\n\tactiveGestures:" << m_activeGestures
-                << "\n\tmaybeGestures:" << m_maybeGestures
-                << "\n\tstarted:" << startedGestures
-                << "\n\ttriggered:" << triggeredGestures
-                << "\n\tfinished:" << finishedGestures
-                << "\n\tcanceled:" << canceledGestures
-                << "\n\tmaybe-canceled:" << maybeToCanceledGestures;
-    }
-
-    QSet<QGesture *> undeliveredGestures;
-    deliverEvents(startedGestures+triggeredGestures+finishedGestures+canceledGestures,
-                  &undeliveredGestures);
-
-    foreach (QGesture *g, startedGestures) {
-        if (undeliveredGestures.contains(g))
-            continue;
-        if (g->gestureCancelPolicy() == QGesture::CancelAllInContext) {
-            DEBUG() << "lets try to cancel some";
-            // find gestures in context in Qt::GestureStarted or Qt::GestureUpdated state and cancel them
-            cancelGesturesForChildren(g);
+        // reset gestures that ended
+        QSet<QGesture *> endedGestures =
+                finishedGestures + canceledGestures + undeliveredGestures + maybeToCanceledGestures;
+        foreach (QGesture *gesture, endedGestures) {
+            recycle(gesture);
+            m_gestureTargets.remove(gesture);
         }
     }
-
-    m_activeGestures -= undeliveredGestures;
-
-    // reset gestures that ended
-    QSet<QGesture *> endedGestures =
-            finishedGestures + canceledGestures + undeliveredGestures + maybeToCanceledGestures;
-    foreach (QGesture *gesture, endedGestures) {
-        recycle(gesture);
-        m_gestureTargets.remove(gesture);
-    }
-
     //Clean up the Gestures
     qDeleteAll(m_gesturesToDelete);
     m_gesturesToDelete.clear();
