@@ -1,38 +1,38 @@
 /****************************************************************************
 **
-** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** GNU Lesser General Public License Usage
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this
-** file. Please review the following information to ensure the GNU Lesser
-** General Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU General
-** Public License version 3.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of this
-** file. Please review the following information to ensure the GNU General
-** Public License version 3.0 requirements will be met:
-** http://www.gnu.org/copyleft/gpl.html.
-**
-** Other Usage
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-**
-**
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
 **
 ** $QT_END_LICENSE$
@@ -757,10 +757,30 @@ void QTextTable::insertColumns(int pos, int num)
     QList<int> extendedSpans;
     for (int i = 0; i < d->nRows; ++i) {
         int cell;
-        if (i == d->nRows - 1 && pos == d->nCols)
+        if (i == d->nRows - 1 && pos == d->nCols) {
             cell = d->fragment_end;
-        else
-            cell = d->grid[i*d->nCols + pos];
+        } else {
+            int logicalGridIndexBeforePosition = pos > 0
+                                                 ? d->findCellIndex(d->grid[i*d->nCols + pos - 1])
+                                                 : -1;
+
+            // Search for the logical insertion point by skipping past cells which are not the first
+            // cell in a rowspan. This means any cell for which the logical grid index is
+            // less than the logical cell index of the cell before the insertion.
+            int logicalGridIndex;
+            int gridArrayOffset = i*d->nCols + pos;
+            do {
+                cell = d->grid[gridArrayOffset];
+                logicalGridIndex = d->findCellIndex(cell);
+                gridArrayOffset++;
+            } while (logicalGridIndex < logicalGridIndexBeforePosition
+                     && gridArrayOffset < d->nRows*d->nCols);
+
+            if (logicalGridIndex < logicalGridIndexBeforePosition
+                && gridArrayOffset == d->nRows*d->nCols)
+                cell = d->fragment_end;
+        }
+
         if (pos > 0 && pos < d->nCols && cell == d->grid[i*d->nCols + pos - 1]) {
             // cell spans the insertion place, extend it
             if (!extendedSpans.contains(cell)) {
