@@ -1,38 +1,38 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** GNU Lesser General Public License Usage
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this
-** file. Please review the following information to ensure the GNU Lesser
-** General Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU General
-** Public License version 3.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of this
-** file. Please review the following information to ensure the GNU General
-** Public License version 3.0 requirements will be met:
-** http://www.gnu.org/copyleft/gpl.html.
-**
-** Other Usage
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-**
-**
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
 **
 ** $QT_END_LICENSE$
@@ -515,6 +515,12 @@ void QLineControl::processInputMethodEvent(QInputMethodEvent *event)
         } else if (a.type == QInputMethodEvent::TextFormat) {
             QTextCharFormat f = qvariant_cast<QTextFormat>(a.value).toCharFormat();
             if (f.isValid()) {
+                if (f.background().color().alphaF() == 1 && f.background().style() == Qt::SolidPattern) {
+                    f.setForeground(f.background().color());
+                    f.setBackground(Qt::transparent);
+                    f.setUnderlineStyle(QTextCharFormat::SingleUnderline);
+                    f.setFontUnderline(true);
+                }
                 QTextLayout::FormatRange o;
                 o.start = a.start + m_cursor;
                 o.length = a.length;
@@ -664,6 +670,8 @@ bool QLineControl::finishChange(int validateFromState, bool update, bool edited)
         m_selDirty = false;
         emit selectionChanged();
     }
+    if (m_cursor == m_lastCursorPos)
+        updateMicroFocus();
     emitCursorPositionChanged();
     return true;
 }
@@ -1202,6 +1210,13 @@ void QLineControl::internalUndo(int until)
         return;
     cancelPasswordEchoTimer();
     internalDeselect();
+
+    // Undo works only for clearing the line when in any of password the modes
+    if (m_echoMode != QLineEdit::Normal) {
+        clear();
+        return;
+    }
+
     while (m_undoState && m_undoState > until) {
         Command& cmd = m_history[--m_undoState];
         switch (cmd.type) {
@@ -1891,6 +1906,21 @@ void QLineControl::processKeyEvent(QKeyEvent* event)
         event->accept();
 }
 
+bool QLineControl::isUndoAvailable() const
+{
+    // For security reasons undo is not available in any password mode (NoEcho included)
+    // with the exception that the user can clear the password with undo.
+    return !m_readOnly && m_undoState
+            && (m_echoMode == QLineEdit::Normal || m_history[m_undoState - 1].type == QLineControl::Insert);
+}
+
+bool QLineControl::isRedoAvailable() const
+{
+    // Same as with undo. Disabled for password modes.
+    return !m_readOnly
+            && m_echoMode == QLineEdit::Normal
+            && m_undoState < m_history.size();
+}
 
 QT_END_NAMESPACE
 
