@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the tools applications of the Qt Toolkit.
@@ -279,9 +279,18 @@ void QDBusViewer::callMethod(const BusSignature &sig)
         args = dialog.values();
     }
 
-    // Special case - convert a value to a QDBusVariant if the
-    // interface wants a variant
+    // Try to convert the values we got as closely as possible to the
+    // dbus signature. this is especially important for those input as strings
     for (int i = 0; i < args.count(); ++i) {
+        QVariant a = args.at(i);
+        int desttype = types.at(i);
+        if (desttype != int(a.type())
+            && desttype < int(QMetaType::LastCoreType) && desttype != int(QVariant::Map)
+            && a.canConvert(QVariant::Type(desttype))) {
+            args[i].convert(QVariant::Type(desttype));
+        }
+        // Special case - convert a value to a QDBusVariant if the
+        // interface wants a variant
         if (types.at(i) == qMetaTypeId<QDBusVariant>())
             args[i] = QVariant::fromValue(QDBusVariant(args.at(i)));
     }
@@ -477,7 +486,7 @@ void QDBusViewer::about()
     box.setText(QString::fromLatin1("<center><img src=\":/trolltech/qdbusviewer/images/qdbusviewer-128.png\">"
                 "<h3>%1</h3>"
                 "<p>Version %2</p></center>"
-                "<p>Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).</p>")
+                "<p>Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).</p>")
             .arg(tr("D-Bus Viewer")).arg(QLatin1String(QT_VERSION_STR)));
     box.setWindowTitle(tr("D-Bus Viewer"));
     box.exec();
