@@ -1593,7 +1593,7 @@ All files (*)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;center&gt;&lt;img src=&quot;:/images/splash.png&quot;/&gt;&lt;/img&gt;&lt;p&gt;%1&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Qt Linguist is a tool for adding translations to Qt applications.&lt;/p&gt;&lt;p&gt;Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).</source>
+        <source>&lt;center&gt;&lt;img src=&quot;:/images/splash.png&quot;/&gt;&lt;/img&gt;&lt;p&gt;%1&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Qt Linguist is a tool for adding translations to Qt applications.&lt;/p&gt;&lt;p&gt;Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -1809,7 +1809,7 @@ All files (*)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Display information about the Qt toolkit by Nokia.</source>
+        <source>Display information about the Qt toolkit by Digia.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
